@@ -5,7 +5,7 @@
 from . import accessors
 
 __author__ = """Philipp Temminghoff"""
-__email__ = 'phil65@kodi.tv'
-__version__ = '0.2.0'
+__email__ = "phil65@kodi.tv"
+__version__ = "0.2.3"
 
 __all__ = ["accessors", "utils"]
